aboutsummaryrefslogtreecommitdiffstats
path: root/node/config.go
diff options
context:
space:
mode:
authorJeffrey Wilcke <jeffrey@ethereum.org>2016-04-12 20:03:21 +0800
committerJeffrey Wilcke <jeffrey@ethereum.org>2016-04-12 20:03:21 +0800
commit8627680e24a29abd5f2aaaeaa2c1c852d8fb693b (patch)
tree1ad39e8b43d04e5a17c17c0b7314eece80620dd5 /node/config.go
parent934f587bd5c38a36e8b8c8647a9e600d1751ff2f (diff)
parentaa9fff3e68b1def0a9a22009c233150bf9ba481f (diff)
downloadgo-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.tar
go-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.tar.gz
go-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.tar.bz2
go-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.tar.lz
go-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.tar.xz
go-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.tar.zst
go-tangerine-8627680e24a29abd5f2aaaeaa2c1c852d8fb693b.zip
Merge pull request #2359 from bas-vk/rpc-optional-args
rpc: several fixes and support for optional arguments
Diffstat (limited to 'node/config.go')
-rw-r--r--node/config.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/node/config.go b/node/config.go
index 301ec636e..23a745c2c 100644
--- a/node/config.go
+++ b/node/config.go
@@ -127,10 +127,10 @@ type Config struct {
// ephemeral nodes).
WSPort int
// WSDomains is the list of domain to accept websocket requests from. Please be
// aware that the server can only act upon the HTTP request the client sends and
// cannot verify the validity of the request header.
- WSDomains string
+ WSOrigins string
// WSModules is a list of API modules to expose via the websocket RPC interface.
// If the module list is empty, all RPC API endpoints designated public will be
@@ -127,10 +127,10 @@ type Config struct {
// ephemeral nodes).
WSPort int
- // WSDomains is the list of domain to accept websocket requests from. Please be
+ // WSOrigins is the list of domain to accept websocket requests from. Please be
// aware that the server can only act upon the HTTP request the client sends and
// cannot verify the validity of the request header.